Struct plaid::holdings::Holding[][src]

pub struct Holding {
    pub account_id: String,
    pub security_id: String,
    pub institution_price: f64,
    pub institution_price_as_of: Option<NaiveDate>,
    pub institution_value: f64,
    pub cost_basis: Option<f64>,
    pub quantity: f64,
    pub iso_currency_code: Option<String>,
    pub unofficial_currency_code: Option<String>,
}

Fields

account_id: String

The Plaid account_id associated with the holding.

security_id: String

The Plaid security_id associated with the holding.

institution_price: f64

The last price given by the institution for this security.

institution_price_as_of: Option<NaiveDate>

The date at which institution_price was current.

institution_value: f64

The value of the holding, as reported by the institution.

cost_basis: Option<f64>

The cost basis of the holding.

quantity: f64

The total quantity of the asset held, as reported by the financial institution.

iso_currency_code: Option<String>

The ISO-4217 currency code of the holding. Always null if unofficial_currency_code is non-null.

unofficial_currency_code: Option<String>

The unofficial currency code associated with the holding.