Struct plaid::holdings::Holding [−][src]
Fields
account_id: StringThe Plaid account_id associated with the holding.
security_id: StringThe Plaid security_id associated with the holding.
institution_price: f64The last price given by the institution for this security.
institution_price_as_of: Option<NaiveDate>The date at which institution_price was current.
institution_value: f64The value of the holding, as reported by the institution.
cost_basis: Option<f64>The cost basis of the holding.
quantity: f64The total quantity of the asset held, as reported by the financial institution.
iso_currency_code: Option<String>The ISO-4217 currency code of the holding. Always null if unofficial_currency_code is non-null.
unofficial_currency_code: Option<String>The unofficial currency code associated with the holding.