Struct plaid::holdings::Security [−][src]
Fields
security_id: StringA unique, Plaid-specific identifier for the security, used to associate securities with holdings. Like all Plaid identifiers, the security_id is case sensitive.
isin: Option<String>12-character ISIN, a globally unique securities identifier.
cusip: Option<String>9-character CUSIP, an identifier assigned to North American securities.
sedol: Option<String>7-character SEDOL, an identifier assigned to securities in the UK.
institution_security_id: Option<String>An identifier given to the security by the institution
institution_id: Option<String>If institution_security_id is present, this field indicates the Plaid institution_id of the institution to whom the identifier belongs.
proxy_security_id: Option<String>In certain cases, Plaid will provide the ID of another security whose performance resembles this security, typically when the original security has low volume, or when a private security can be modeled with a publicly traded security.
name: Option<String>A descriptive name for the security, suitable for display.
ticker_symbol: Option<String>The security’s trading symbol for publicly traded securities, and otherwise a short identifier if available.
is_cash_equivalent: boolIndicates that a security is a highly liquid asset and can be treated like cash.
type: Option<String>The security type of the holding.
close_price: Option<f64>Price of the security at the close of the previous trading session. null for non-public securities.
close_price_as_of: Option<NaiveDate>Date for which close_price is accurate. Always null if close_price is null.
iso_currency_code: Option<String>The ISO-4217 currency code of the price given. Always null if unofficial_currency_code is non-null.
unofficial_currency_code: Option<String>The unofficial currency code associated with the security.